require_relative '../../test_helper'

describe Myredditnews::Entry do
  before do
    @entry = Myredditnews::Entry.new do
      author "david"
      content "lorem ipsum"
      url "google.com"
      date "tomorrow"
      title "my title"
    end
  end

  it 'can be serialized to json' do
    js = JSON.parse(@entry.to_json)
    js["author"].must_equal "david"
    js["content"].must_equal "lorem ipsum"
    js["date"].must_equal "tomorrow"
    js["title"].must_equal "my title"
    js["url"].must_equal "google.com"
  end

  it 'can be parsed from json' do
    json = <<END
    {
      "author"  : "rudi",
      "content" : "boring",
      "date"    : "yesterday",
      "title"   : "testing123",
      "url"     : "testing.com"
    }
END
    entry = Myredditnews::Entry(JSON.parse(json))
    entry.author.must_equal "rudi"
    entry.content.must_equal "boring"
    entry.date.must_equal "yesterday"
    entry.title.must_equal "testing123"
    entry.url.must_equal "testing.com"
  end

  it 'respects delay when submitting' do
    reddit_mock = MiniTest::Mock.new
    reddit_mock.expect(:submit,
                       {'json' => {'errors' => []}}, [String, String, Hash])
    @new_delay = 0.05
    @now = Time.now.to_f
    Myredditnews.with_dry false do
      Myredditnews.with_delay 0.05 do
        @entry.submit(reddit_mock, 'my_subreddit')
        refute_in_delta @now, Time.now.to_f, @new_delay
      end
    end
    reddit_mock.verify
  end
end

